@@ -381,7 +381,7 @@ test_that("extract fixest objects created with the fixest package", {
   firm.eff <- rnorm(nlevels(data$firm))
   u <- rnorm(length(x))
   data$y <- with(data, x + 0.5 * x2 + id.eff[id] + firm.eff[firm] + u)
-  est <- feols(y ~ x + x2 | id + firm, data = data)
+  est <- feols(y ~ x + x2 | id + firm, vcov = "cluster", data = data)
 
   tr <- extract(est)
 
@@ -402,7 +402,7 @@ test_that("extract fixest objects created with the fixest package", {
   tr <- extract(est)
 
   expect_equivalent(tr@coef, c(1.00, 1.00), tolerance = 1e-2)
-  expect_equivalent(tr@se, c(0.01, 0.02), tolerance = 1e-2)
+  expect_equivalent(tr@se, c(0.01, 0.02), tolerance = 1e-1)
   expect_equivalent(tr@pvalues, c(0.00, 0.00), tolerance = 1e-2)
   expect_equivalent(tr@gof, c(1000, 20, 955.4, -1479.6, 0.83), tolerance = 1e-2)
   expect_length(tr@gof.names, 5)
@@ -854,6 +854,30 @@ test_that("extract pcce objects from the plm package", {
   expect_equivalent(which(tr2@gof.decimal), 1:3)
 })
 
+# prais (prais) ----
+test_that("extract prais objects from the prais package", {
+  testthat::skip_on_cran()
+  skip_if_not_installed("prais", minimum_version = "1.1.3")
+  set.seed(12345)
+  data("barium", package = "prais")
+
+  output <- capture.output({
+    pwmod <- prais::prais_winsten(lchnimp ~ lchempi + lgas + lrtwex + befile6 + affile6 + afdec6, data = barium, index = "t")
+  }, file = NULL)
+
+  tr <- extract(pwmod)
+  expect_length(tr@coef.names, 8)
+  expect_length(tr@coef, 8)
+  expect_length(tr@se, 8)
+  expect_length(tr@pvalues, 8)
+  expect_length(tr@ci.low, 0)
+  expect_length(tr@ci.up, 0)
+  expect_length(tr@gof, 3)
+  expect_length(tr@gof.names, 3)
+  expect_length(tr@gof.decimal, 3)
+  expect_equivalent(which(tr@gof.decimal), 1:2)
+})
+
 # remstimate (remstimate) ----
 test_that("extract remstimate objects from the remstimate package", {
   testthat::skip_on_cran()
@@ -934,15 +958,17 @@ test_that("extract Sarlm objects from the spatialreg package", {
   ev <- spatialreg::eigenw(listw)
   W <- as(listw, "CsparseMatrix")
   trMatc <- spatialreg::trW(W, type = "mult")
-  sink(nullfile())
-  COL.lag.eig <- spatialreg::lagsarlm(CRIME ~ INC + HOVAL,
-                                      data = COL.OLD,
-                                      listw = listw,
-                                      method = "eigen",
-                                      quiet = FALSE,
-                                      control = list(pre_eig = ev,
-                                                     OrdVsign = 1))
-  sink()
+
+  output <- capture.output({
+    COL.lag.eig <- spatialreg::lagsarlm(CRIME ~ INC + HOVAL,
+                                        data = COL.OLD,
+                                        listw = listw,
+                                        method = "eigen",
+                                        quiet = FALSE,
+                                        control = list(pre_eig = ev,
+                                                       OrdVsign = 1))
+  }, file = NULL)
+
   tr <- extract(COL.lag.eig)
   expect_length(tr@coef.names, 4)
   expect_length(tr@coef, 4)
